#
# spec file for package perl-Net-Server
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Net-Server
Version:        2.008
Release:        6.1
%define cpan_name Net-Server
Summary:        Extensible, general Perl server engine
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Net-Server/
Source:         http://www.cpan.org/authors/id/R/RH/RHANDOM/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl(IO::Socket)
BuildRequires:  perl(POSIX)
BuildRequires:  perl(Socket)
BuildRequires:  perl-macros
Requires:       perl(IO::Socket)
Requires:       perl(POSIX)
Requires:       perl(Socket)
%{perl_requires}

%description
'Net::Server' is an extensible, generic Perl server engine. 'Net::Server'
combines the good properties from 'Net::Daemon' (0.34),
'NetServer::Generic' (1.03), and 'Net::FTPServer' (1.0), and also from
various concepts in the Apache Webserver.

'Net::Server' attempts to be a generic server as in 'Net::Daemon' and
'NetServer::Generic'. It includes with it the ability to run as an inetd
process ('Net::Server::INET'), a single connection server ('Net::Server' or
'Net::Server::Single'), a forking server ('Net::Server::Fork'), a
preforking server which maintains a constant number of preforked children
('Net::Server::PreForkSimple'), or as a managed preforking server which
maintains the number of children based on server load
('Net::Server::PreFork'). In all but the inetd type, the server provides
the ability to connect to one or to multiple server ports.

'Net::Server' uses ideologies of 'Net::FTPServer' in order to provide
extensibility. The additional server types are made possible via
"personalities" or sub classes of the 'Net::Server'. By moving the multiple
types of servers out of the main 'Net::Server' class, the 'Net::Server'
concept is easily extended to other types (in the near future, we would
like to add a "Thread" personality).

'Net::Server' borrows several concepts from the Apache Webserver.
'Net::Server' uses "hooks" to allow custom servers such as SMTP, HTTP,
POP3, etc. to be layered over the base 'Net::Server' class. In addition the
'Net::Server::PreFork' class borrows concepts of min_start_servers,
max_servers, and min_waiting servers. 'Net::Server::PreFork' also uses the
concept of an flock serialized accept when accepting on multiple ports
(PreFork can choose between flock, IPC::Semaphore, and pipe to control
serialization).

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples/ README

%changelog
* Tue May 13 2014 aj@ajaissle.de
- Updated to new upstream version 2.008
- Changelog 2.008  May 12 2014
  * Long awaited patch for the IO::Socket::SSL default verify mode bug
  * Add Time::HiRes as a dep
  * Update to new github hosted repository with all legacy code imported
  * Beginnings of change to dzil based releases
  * There are several dozen outstanding bugs that will be addressed in the next release
* Tue Feb  5 2013 aj@ajaissle.de
- updated to new upstream version 2.007
- Changelog 2.007  Jan 09 2013
  * Update run_dequeue to clear out signals after fork.
  * Add serialize none for PreFork and PreForkSimple servers that at not multi-port.
  * Allow for auto-assigned port to be the same when hostname resolves to multiple ips/ipvs (RT #78024)
  * Fix bug in header parsing (RT #82125)
  * Fix warning bug (RT #78828)
  * Fix wrong wantarray context in Proto::TCP (RT #31437)
  * Simplify _get_commandline to just use $0 - no fishing in proc (RT #80260)
  * Fix uninitialized begin (RT #78830)
  * Fix misplaced +2 (RT #78827)
  * Fix various spelling errors and pod nits (RT #77994)
  * Allow for log calls from the MUX object (RT #78514)
  * Give an error at begin time of SSLEAY if the need Fcntl function is not available on this platform (RT #82542)
  * Make all of the tests self cancel much earlier if there is an error handling the request.
  * Add a stronger timeout to PreFork tests - ideally we'd like to find a real way to test these one windows (RT #811411, #81993) - still broken - but shouldn't hang
  * Superficial changes to help packagers not list Log4perl as dependency (it is optional)
* Tue Feb  5 2013 aj@ajaissle.de
- Skipped the following upstream releases:
- Changelog 2.006  Jun 20 2012
  * Allow for case where host is *, and IO::Socket::INET6 is installed, but IPv6 doesn't really work.
  * Add missing child_init_hook in Fork server (so Fork can be more parallel with PreFork in some respects)
  * Change BOUND_SOCKETS passing to use ; as a separator rather than a \n
- Changelog 2.005  Jun 12 2012
  * NOTE: ipv now defaults to *
  * Change the default of ipv from 4 to *.  This means if a host of * (default), or a named host is used, any available IPv4 OR IPv6 address will be used.
  * Allow for explicit close_client_stdout call
  * Add dispatch methods and app setup to HTTP
  * Allow for exec_fork_hook in HTTP
  * Make sure errors in HTTP use correct logging mechanisms (and do not die un-needed)
  * Fix 500 call in PSGI
  * Fix send_header
- Changelog 2.004  Jun 08 2012
  * NOTE: Version 2.005 will change the default ipv value to * meaning it will attempt to bind IPv4 and IPv6 if they are available if you pass a hostname
  * Add Net::Server::Proto->get_addr_info which can more reliably resolve domain information.
  * Use that information to figure out an appropriate host to bind to for tests
  * Make get_addr_info less reliant on magic values of sysctl net.ipv6.bindv6only
  * Allow all tests to function in IPv6 only environments
  * Fix broken number of tests in test suite
  * Add warnings about changes to the default value of ipv coming in 2.005
- Changelog 2.003  Jun 06 2012
  * Make the logging system pluggable
  * Added net-server server executor for writing easier one line servers
  * Sys::Syslog and Log::Log4perl are now moved out to their own module subsystems
  * Added full apache style HTTP log formatting for the HTTP server
  * Allow for ipv to be specified as part of host, or proto, or passed via $ENV{'IPV'}
  * Add apache style access logging (access_log_file and access_log_format) to HTTP
  * Allow HTTP header parsing to not untaint the headers (thanks Miko O'Sullivan)
  * Fix missing legacy NS_unix_path call (missing since 2.000)
  * Fix a bug in MultiType that prevented calling server_type HTTP
- Changelog 2.002  May 31 2012
  * Make HTTP output header parsing more consistent - and catch more errors
  * Add exec_cgi and exec_trusted_perl methods to HTTP
  * Add bugfix for ipv=>"*" combined with UNIX sockets. (Mark Martinec)
  * Fix the SSL_test.t to use exit rather than quit so the parent departs
- Changelog 2.001  May 30 2012
  * Bug fix wrong usage of File::Temp::tempfile.
  * Fix HTTP_COOKIES to be HTTP_COOKIE
  * Handle multiple header values better in HTTP
  * Add Log::Log4perl logging courtesy of TONVOON@cpan
- Changelog 2.000  May 30 2012
  * Bring Net::Server::Proto::SSL back.  It is now fully functional under all scenarios, including IPv4 and IPv6
  * Change Proto interface to allow passing more information.  This represents an internal API change.
  * Updates to the HUP mechanisms to make sure we rebind all types of ports correctly.
  * Add IPv6 integration via ::1 style addresses as well as the ipv configuration parameter (Mark Martinec)
  * Added graceful shutdown (Tatsuhiko Miyagawa)
  * Added hot deploy via TTIN and TTOU (Tatsuhiko Miyagawa)
  * Internal code retidying
  * Finish out support for connecting to ports by service name
  * Don't loose track of fork and prefork children on a hup - make sure to actively wait them off
  * Correct accept to take a classname, and optionally be called in array context
  * Cleanup numerous configuration issues.
  * Added sig_passthrough option to Fork, PreFork, and PreForkSimple servers allowing for arbitrary signals to propagate to children
  * Add syswrite/sysread support to SSLEAY (Sergey Zasenko).
  * Add PSGI module.
  * Many small accumulated bugfixes.
* Tue Dec  6 2011 coolo@suse.com
- regenerate with cpanspec to fix license
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul 20 2010 chris@computersalat.de
- disable "dubiuos" failing test
  o t/Server_http.t
* Sat Jul 17 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
- added examples to doc
* Fri Jul 16 2010 anicka@suse.cz
- update to 0.99
  * Add customizable  check_for_spawn and min_child_ttl settings in PreFork (Graham Barr)
  * Add other_child_died_hook (Daniel Kahn Gillmor)
  * Make Multiplex do $mux->add($sock) for UDP sockets (Kristoffer Møllerhøj)
  * Change Net::Server::Daemonize to use kill 0 rather than the unportable `ps`
  * Fix calling conventions of MultiType
  * Avoid select in SSLEAY that was allowing for infinite spin loop
  * Fix tie_stdout mode to not warn about unopen handles.
  * Added Net::Server::HTTP base class for basic HTTP daemon handling.
  * Change examples/httpd to use Net::Server::HTTP
  * Add SSLeay proto - finally a workable SSL solution.
  * Add minimal Net::Server::TiedHandle to allow for STDIN and STDOUT to work with SSLEAY
  * Net::Server::TiedHandle also support tied_stdin_callback and tied_stdout_callback
  * Allow for port => 0 which lets the OS auto assign a port on some OSes (Blackie Hlasek)
  * Add idle_loop_hook to PreForkSimple and PreFork (David Zuhn)
  * Add consistent formatting capabilities to the log method (whethere Syslog is used or not) (David Zuhn)
  * Warn when default listen value is used - try to make it a sensible default (Mark Martinec)
  * Allow for non-zero exit value - particularly when called from fatal (David Schweikert)
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Oct  8 2007 anicka@suse.cz
- update to 0.97
  * Allow for better handling of setlogsock depending upon
    the version of Sys::Syslog installed
  * Update examples with minimal pod and working synopses
  * Added post_client_connection_hook
* Fri Mar 30 2007 anicka@suse.cz
- update to 0.96
  * Allow for conf_file to be specified in the default_values.
  * Add perldoc for why we use a template in options.
  * Fix syslog log options regex again (Carlos Velasco)
  * Fix ->autoflush (needs FileHandle)
  * Add handle_syslog_error to allow catching errors
    during syslog writes
  * Add open_syslog to slightly abstract opening of syslog.
  * Add numerous patches to cleanup child accounting in PreFork
    server.
* Wed Feb 14 2007 anicka@suse.cz
- update to 0.95
- Warn clean on the chld hanlder in PreFork.
  * Allow lock_file for lock serialization to only be opened once
  * Add additional log messages during failure in accept
  * Fix double decrement bug in PreFork.pm
  * Fix precedence bug with non-parened open
  * Check setuid better after POSIX setuid
  * Update Syslog options parsing
  * Allow no_client_stdout to work with Multiplex
  * Allow Sys::SysLog keyworks be passed through the ->log method
  * Allow more characters through in syslog_ident
  * Fix Fork server bug which had post_accept_hook called twice
  * Added pre_fork_hook to Fork server to handle removed duplicate
    post_accept_hook call.
  * Reopen STDIN/STDOUT to /dev/null at end of child connection
    to avoid spurious warnings
  * Don't process STDIN/STDOUT in post_accept if udp_true
  * Cleanup child processing code in PreFork server
  * Try and let tests fail gracefully if localhost is not setup
    properly
  * Add numerous tests for configuration passing.
  * Add perldoc about adding your own custom options
* Tue Oct 24 2006 anicka@suse.cz
- add perl-IO-Multiplex to Requires (#207466)
* Fri Sep 29 2006 anicka@suse.cz
- update to 0.94
  * Added the leave_children_open_on_hup flag which leaves
    open connections open when the server is hupped.
  * Allow for port, host, and proto to be passed as arrayrefs
    to run and new.
  * Allow for get sock info routines to use $peer->{client}
    rather than STDIN which may not be set if
    the "no_client_stdout" flag is set.
  * Allow for duplicated STDIN and STDOUT to properly close.
  * Add flag to disable all of the binding of client
    to STDIN and STDOUT.
  * Abstract shutdown_sockets method that is called at the end
    of server_close (to allow for calling in other places).
  * bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec  8 2005 sf@suse.de
- update to 0.90
* Sun Jul 31 2005 cthiel@suse.de
- update to version 0.88
- dropped perl-Net-Server-format-string.diff (fixed in 0.88)
* Wed Apr 20 2005 sf@suse.de
- corrected patch for #78095 - VUL-0
* Mon Apr 18 2005 sf@suse.de
- fix for #78095 - VUL-0
  check for format string and create formatted string.
  if there is no format string, just take the first string
* Thu Feb 26 2004 choeger@suse.de
- update to most recent version 0.87
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 28 2003 choeger@suse.de
- use install_vendor and new %%perl_process_packlist macro
- updated to version 0.85
* Mon Jun 23 2003 ro@suse.de
- added directories to filelist
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon Dec  2 2002 sf@suse.de
- initial version 0.84
